﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Controls;
using System.ComponentModel;
using System.Diagnostics;

using System.Windows.Data;
using System.Xml;
using Infragistics.Windows;

namespace xamGridXmlFiltering
{
    public static class DataPresenterHelpers
    {
        #region FilterText

        /// <summary>
        /// FilterText Attached Dependency Property
        /// </summary>
        public static readonly DependencyProperty FilterTextProperty =
            DependencyProperty.RegisterAttached("FilterText", typeof(string), typeof(DataPresenterHelpers),
                new FrameworkPropertyMetadata((string)null,
                    new PropertyChangedCallback(OnFilterTextChanged)));

        /// <summary>
        /// Gets the text to be used to filter the DataPresenter on which the property was set.
        /// </summary>
        public static string GetFilterText(DependencyObject d)
        {
            return (string)d.GetValue(FilterTextProperty);
        }

        /// <summary>
        /// Sets the filter text on the DataPresenter that should be used to manipulate the RecordFilters of the specified DataPresenter
        /// </summary>
        public static void SetFilterText(DependencyObject d, string value)
        {
            d.SetValue(FilterTextProperty, value);
        }

        /// <summary>
        /// Handles changes to the FilterText property.
        /// </summary>
        private static void OnFilterTextChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var dp = d as XamDataGrid;

            if (dp.FieldLayouts.Count < 1)
                return;

            foreach (var layout in dp.FieldLayouts)
                layout.RecordFilters.Clear();
           

            var filter = new RecordFilter {FieldName = "Name"};
            filter.Conditions.Add(new ComparisonCondition(ComparisonOperator.Contains, e.NewValue));
            dp.FieldLayouts["SyncSubHeader"].RecordFilters.Add(filter);

            //foreach (var layout in dp.FieldLayouts)
            //{
            //    RecordFilterCollection recordFilterCollection = layout.RecordFilters;
            //    recordFilterCollection.Clear();
            //    if (!string.IsNullOrEmpty(e.NewValue as string))
            //    {
            //        foreach (var field in layout.Fields)
            //        {
            //                var filter = new RecordFilter();
            //                filter.Field = field;
            //                filter.Conditions.Add(new ComparisonCondition(ComparisonOperator.Contains, e.NewValue));
            //                recordFilterCollection.Add(filter);
            //        }
            //    }
            //    layout.Settings.RecordFiltersLogicalOperator = LogicalOperator.Or;
          //  }

            

        }

        

        #endregion //FilterText
    }
}
